@@ -1,11 +1,13 @@
-import pandas as pd
 import numpy as np
+import itertools
 import pytest
+import pandas as pd
 
 from stock_pandas import StockDataFrame
 from .common import (
     simple_list,
-    create_stock
+    create_stock,
+    get_stock_update
 )
 
 
@@ -26,6 +28,10 @@ def test_astype(stock):
     assert isinstance(open0, float)
 
 
+def test_indexing_by_callable(stock):
+    assert isinstance(stock[lambda df: 'open'], pd.Series)
+
+
 def test_ma(stock):
     stock.alias('Open', 'open')
 
@@ -38,25 +44,38 @@ def test_ma(stock):
     assert np.isnan(ma[0])
     assert list(ma[1:]) == list_ma0
 
-    new = pd.DataFrame(dict(
-        open=[8],
-        close=[9],
-        high=[18],
-        low=[7],
-        volume=[800]
-    ))
+    new = get_stock_update()
 
     stock = stock.append(new, ignore_index=True)
     assert isinstance(stock, StockDataFrame)
 
     ma2 = stock.exec('ma:2')
 
-    print(ma2)
+    assert np.isnan(ma2[0])
 
     assert list(ma2[1:]) == [*list_ma0, 8.5]
     assert stock['Open'][0] == 2
 
 
+COMMANDS = [
+    'ma:{}',
+    'macd.signal',
+    'rsi:{}'
+]
+
+
+def test_period_larger_than_size(stock):
+    period = len(stock) + 1
+
+    for command in COMMANDS:
+        directive_str = command.format(period)
+        result = stock.exec(directive_str)
+
+        assert np.all(
+            np.isnan(result)
+        ), directive_str
+
+
 def test_aliases(stock):
     stock.alias('Open', 'open')
     assert list(stock['Open']) == simple_list
@@ -71,3 +90,19 @@ def test_aliases(stock):
 def test_invalid_indexing(stock):
     with pytest.raises(KeyError, match='None'):
         stock[[1]]
+
+
+def test_multi_index():
+    tuples = list(itertools.product(
+        ['foo', 'bar'],
+        ['one', 'two']
+    ))
+
+    columns = pd.MultiIndex.from_tuples(tuples, names=['first', 'second'])
+
+    with pytest.raises(ValueError, match='MultiIndex'):
+        StockDataFrame(
+            np.random.randn(3, 4),
+            index=['A', 'B', 'C'],
+            columns=columns
+        )
